@@ -27,7 +27,7 @@ from hicstuff.log import logger
 
 
 def process_read_pair(line):
-    """Process and order read pairs in a .pairs record.
+    r"""Process and order read pairs in a .pairs record.
 
     Takes a read pair (line) from a .pairs file as input, reorders the pair
     so that read 1 in intrachromosomal pairs always has the smallest genomic
@@ -49,7 +49,7 @@ def process_read_pair(line):
 
     Examples
     --------
-        >>> d = process_read_pair("readX a 1 b 20 - - 1 3")
+        >>> d = process_read_pair("readX\ta\t1\tb\t20\t-\t-\t1\t3")
         >>> for u in sorted(d.items()):
         ...     print(u)
         ('chr1', 'a')
@@ -63,12 +63,12 @@ def process_read_pair(line):
         ('strand1', '-')
         ('strand2', '-')
         ('type', 'inter')
-        >>> d = process_read_pair('readY a 20 a 10 - + 2 1')
+        >>> d = process_read_pair('readY\ta\t20\ta\t10\t-\t+\t2\t1')
         >>> [d[x] for x in sorted(d.keys())]
         ['a', 'a', 1, 2, 1, 10, 20, 'readY', '+', '-', '+-']
     """
     # Split line by whitespace
-    p = line.split(" ")
+    p = line.split("\t")
     if len(p) != 9:
         raise ValueError(
             "Your input file does not have 9 columns. Make sure "
@@ -199,11 +199,10 @@ def get_thresholds(
 
         except Exception:
             logger.error(
-                "Unable to show plots. Perhaps there is no Xserver running ? "
-                "(might be due to windows environment). Try running without "
-                "the interactive option."
+                "Unable to show plots, skipping figure generation. Perhaps "
+                "there is no Xserver running ? (might be due to windows "
+                "environment). Try running without the interactive option."
             )
-            raise
 
         # Asks the user for appropriate thresholds
         print(
@@ -236,9 +235,15 @@ def get_thresholds(
         for site in range(max_sites)[:1:-1]:
             # For uncuts and loops, keep the last (closest) site where the
             # deviation from other events <= expected_stdev
-            if abs(np.log(n_events["+-"][site]) - event_med[site]) <= exp_stdev:
+            if (
+                abs(np.log(n_events["+-"][site]) - event_med[site])
+                <= exp_stdev
+            ):
                 thr_uncut = site
-            if abs(np.log(n_events["-+"][site]) - event_med[site]) <= exp_stdev:
+            if (
+                abs(np.log(n_events["-+"][site]) - event_med[site])
+                <= exp_stdev
+            ):
                 thr_loop = site
         if thr_uncut is None or thr_loop is None:
             raise ValueError(
@@ -314,7 +319,9 @@ def get_thresholds(
                 plt.axvline(x=thr_uncut, color=colors["+-"])
 
                 if prefix:
-                    plt.title("Library events by distance in {}".format(prefix))
+                    plt.title(
+                        "Library events by distance in {}".format(prefix)
+                    )
                 plt.tight_layout()
                 if fig_path:
                     plt.savefig(fig_path)
@@ -324,11 +331,10 @@ def get_thresholds(
 
             except Exception:
                 logger.error(
-                    "Unable to show plots. Is an X server running?"
-                    "(might be due to windows environment)."
-                    "Try running without the plot option."
+                    "Unable to show plots, skipping figure generation. Is "
+                    "an X server running? (might be due to windows "
+                    "environment). Try running without the plot option."
                 )
-                raise
     return thr_uncut, thr_loop
 
 
@@ -386,7 +392,7 @@ def filter_events(
 
             p = process_read_pair(line)
             line_to_write = (
-                " ".join(
+                "\t".join(
                     map(
                         str,
                         (
@@ -421,7 +427,9 @@ def filter_events(
                 filtered.write(line_to_write)
 
     if lrange_inter > 0:
-        ratio_inter = round(100 * lrange_inter / float(lrange_intra + lrange_inter), 2)
+        ratio_inter = round(
+            100 * lrange_inter / float(lrange_intra + lrange_inter), 2
+        )
     else:
         ratio_inter = 0
 
@@ -439,7 +447,9 @@ def filter_events(
         )
     )
     logger.info(
-        "{0} pairs kept ({1}%)".format(kept, round(100 * kept / (kept + discarded), 2))
+        "{0} pairs kept ({1}%)".format(
+            kept, round(100 * kept / (kept + discarded), 2)
+        )
     )
 
     # Visualize summary if requested by user
@@ -448,13 +458,23 @@ def filter_events(
             # Plot: make a square figure and axes to plot a pieChart:
             plt.figure(2, figsize=(6, 6))
             # The slices will be ordered and plotted counter-clockwise.
-            labels = "Uncuts", "Loops", "Weirds", "3D intra", "3D inter"
             fracs = [n_uncuts, n_loops, n_weirds, lrange_intra, lrange_inter]
-            colors = ["salmon", "lightskyblue", "yellow", "palegreen", "plum"]
-            patches, _, _ = plt.pie(
-                fracs, colors=colors, autopct="%1.1f%%", startangle=90
+            # Format labels to include event names and proportion
+            labels = list(
+                map(
+                    lambda x: (x[0] + ": %.2f%%") % (100 * x[1] / total),
+                    [
+                        ("Uncuts", n_uncuts),
+                        ("Loops", n_loops),
+                        ("Weirds", n_weirds),
+                        ("3D intra", lrange_intra),
+                        ("3D inter", lrange_inter),
+                    ],
+                )
             )
-            plt.legend(patches, labels, loc="best")
+            colors = ["salmon", "lightskyblue", "yellow", "palegreen", "plum"]
+            patches, _ = plt.pie(fracs, colors=colors, startangle=90)
+            plt.legend(patches, labels, loc=2)
             if prefix:
                 plt.title(
                     "Distribution of library events in {}".format(prefix),
@@ -512,4 +532,3 @@ def filter_events(
                 "(might be due to windows environment) skipping figure "
                 "generation."
             )
-            raise
